*
*==================================================
*
*   TEMP1A.asm      Temperature Sensor Example  
*                                 
*   Version:        1.0   Released 01/30/2004
*   Author:         Gary Karnes 
*   Compiler:       As11
*   Platform:       Axiom CME-11E9 EVBU
*   Purpose:        Read a temperature sensor  
*==================================================
*
*  Example: Fahrenheit Temperature Sensor
*           LM34
*  Results: Displays the temperature in Fahrenheit
*           Note: Only 2 degrees resolution
*     Math: A = Value read in hex
*           B = value of each step (.0194 * 10000 = 194)
*            Temperature = (A * 194)/100) 
*           
*        Analog Register Equates
ADCTL:       equ     $1030        * Analog Control Register
ADR3:        equ     $1033        * CH6 Analog Result
OPTION:      equ     $1039        * Analog Enable Register
OUTPUT:      equ     $FFAF        ; Buffalo output routine
OUTRHLF:     equ     $FFB5        ; Buffalo routine right nibble to AscII
* Buffalo Routines
OUTCRLF:     equ     $FFC4        * car/line feed
OUT1BYT:     equ     $FFBB        * Display Byte as hex
TEMP:        equ     $01fe        * temp storage

*
* Setup the A/D converter
             org     $0100          * program starts here
             ldaa    #$80           * Turn A/D On
             staa    OPTION         *
             ldaa    #$36           * Select PE6, multi conversions
             staa    ADCTL          * Setup A/D
* Display Results             
Loop2
             jsr     OUTCRLF        * new line
             jsr     Delay
* read value & calculate temperature
             ldab    #194           * Multi factor
             ldaa    ADR3           * read 8-bit conversion
             mul                    * Multipl Unsigned D=Result
             ldx     #100           * divide factor
             idiv
             pshx                   * save value
             puly                   * move to y
             bsr     HexDec         * convert hex to decimal
             ldx     #TEMP          * point to data
             std     0,x            * save result
             std     0,x
             jsr     OUT1BYT        * send high byte
             jsr     OUT1BYT        * send low byte    
             bra     Loop2          * display next digit
*
* calculate Decimal Temperature
* Input: Y should contain hex
* Output: D should contain Decimal
HexDec:
             clra
             clrb
HexDecL:
             cmpy    #$0000
             beq     HexDecE
             dey     decrement y
             adda    #$01         * add one to A
             daa                  * Decimal adjust
             bcc     HexDecK      * skip over if carry not set
             addb    #$01         * add one to B
HexDecK:
             bra     HexDecL      * repeat until y = 0  
HexDecE:
* exchange A & B
             pshb
             tab                  * transfer a to b
             pula                 * get A
             rts
*
* Delay
Delay:
             ldab    #$10
DelayB
             ldy     #$FFFF 
DelayA:      
             dey                  
             bne     DelayA
             decb    
             bne     DelayB
             rts
*
